==> Paws-0.33.tar.gz: Paws-0.33/lib/Paws/MTurk/HITLayoutParameter.pm <==
package Paws::MTurk::HITLayoutParameter;
  use Moose;
  has Name => (is => 'ro', isa => 'Str');
  has Value => (is => 'ro', isa => 'Str');
1;

### main pod documentation begin ###

=head1 NAME

Paws::MTurk::HITLayoutParameter

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::MTurk::HITLayoutParameter object:

  $service_obj->Method(Att1 => { Name => $value, ..., Value => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::MTurk::HITLayoutParameter object:

  $result = $service_obj->Method(...);
  $result->Att1->Name

=head1 DESCRIPTION

The HITLayoutParameter data structure defines parameter values used
with a HITLayout. A HITLayout is a reusable Amazon Mechanical Turk
project template used to provide Human Intelligence Task (HIT) question
data for CreateHIT.

=head1 ATTRIBUTES


=head2 Name => Str

  The name of the parameter in the HITLayout.


=head2 Value => Str

  The value substituted for the parameter referenced in the HITLayout.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::MTurk>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.36.tar.gz: Paws-0.36/lib/Paws/MTurk/HITLayoutParameter.pm <==
package Paws::MTurk::HITLayoutParameter;
  use Moose;
  has Name => (is => 'ro', isa => 'Str', required => 1);
  has Value => (is => 'ro', isa => 'Str', required => 1);
1;

### main pod documentation begin ###

=head1 NAME

Paws::MTurk::HITLayoutParameter

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::MTurk::HITLayoutParameter object:

  $service_obj->Method(Att1 => { Name => $value, ..., Value => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::MTurk::HITLayoutParameter object:

  $result = $service_obj->Method(...);
  $result->Att1->Name

=head1 DESCRIPTION

The HITLayoutParameter data structure defines parameter values used
with a HITLayout. A HITLayout is a reusable Amazon Mechanical Turk
project template used to provide Human Intelligence Task (HIT) question
data for CreateHIT.

=head1 ATTRIBUTES


=head2 B<REQUIRED> Name => Str

  The name of the parameter in the HITLayout.


=head2 B<REQUIRED> Value => Str

  The value substituted for the parameter referenced in the HITLayout.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::MTurk>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut
